# Membership-function-visualization
Plotting various membership functions with matplotlib

### Installation  
Mfvis requires an installation of Python 3.6 or greater, as well as pip. (Pip is typically bundled with Python [installations](https://python.org/downloads).)

To install from PyPI with pip:

```bash
$ python -m pip install mfvis
```
Install the required packages: 
```bash
$ python -m pip install -r requirements.txt
```
### Using mfvis
To start the script through the cli:
```bash
$ python -m mfvis
```


Example: S-function: <br>  

![example-S-function](https://github.com/MaxWolf-01/Membership-function-visualization/blob/master/example.png)  

![example-S-function-Cli](https://github.com/MaxWolf-01/Membership-function-visualization/blob/master/example1.png)
